OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Storage invalid" : "Speicher ungültig",
    "Unknown error" : "Unbekannter Fehler",
    "File could not be found" : "Datei konnte nicht gefunden werden",
    "Move or copy" : "Verschieben oder kopieren",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "Home" : "Home",
    "Close" : "Schließen",
    "Favorites" : "Favoriten",
    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
    "This will stop your current uploads." : "Hiermit werden die aktuellen Uploads angehalten.",
    "Upload cancelled." : "Hochladen abgebrochen.",
    "Processing files …" : "Dateien werden verarbeitet…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
    "Not enough free space" : "Nicht genügend freier Speicherplatz",
    "An unknown error has occurred" : "Es ist ein unbekannter Fehler aufgetreten",
    "File could not be uploaded" : "Datei konnte nicht hochgeladen werden.",
    "Uploading …" : "Lade hoch…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Hochladen von Daten dieser Art wird nicht unterstützt.",
    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
    "Operation is blocked by access control" : "Vorgang wird durch die Zugangskontrolle blockiert",
    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
    "Actions" : "Aktionen",
    "Rename" : "Umbenennen",
    "Move" : "Verschieben",
    "Copy" : "Kopieren",
    "Choose target folder" : "Zielordner wählen",
    "Open" : "Öffnen",
    "Delete file" : "Datei löschen",
    "Delete folder" : "Ordner löschen",
    "Disconnect storage" : "Speicher trennen",
    "Leave this share" : "Diese Freigabe verlassen",
    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
    "Files" : "Dateien",
    "Details" : "Details",
    "Show list view" : "Listenansicht anzeigen",
    "Show grid view" : "Rasteransicht anzeigen",
    "Please select tag(s) to add to the selection" : "Bitte wähle das/die Schlagwort(e) aus, das/die du zur Auswahl hinzufügen möchtest",
    "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
    "Select directory \"{dirName}\"" : "Verzeichnis \"{dirName}\" auswählen",
    "Select file \"{fileName}\"" : "Datei \"{fileName}\" auswählen",
    "Pending" : "Ausstehend",
    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder den Administrator kontaktieren.",
    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
    "copy" : "Kopie",
    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
    "{newName} already exists" : "{newName} existiert bereits",
    "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte einen anderen Namen verwenden.",
    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden, da diese bereits existiert.",
    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden, da dieser bereits existiert",
    "Could not fetch file details \"{file}\"" : "Details zu \"{file}\" konnten nicht ermittelt werden",
    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Gebe mehr als zwei Zeichen ein, um in anderen Ordnern zu suchen",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "{dirs} and {files}" : "{dirs} und {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n versteckte eingeschlossen","%n versteckte eingeschlossen"],
    "You do not have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
    "Select file range" : "Dateibereich auswählen",
    "{used} of {quota} used" : "{used} von {quota} verwendet",
    "{used} used" : "{used} verwendet",
    "\"{name}\" is an invalid file name." : "„{name}“ ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ ist kein erlaubter Dateityp",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppenordner \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externer Speicher \"{mountPoint}\" ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppenordner \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externer Speicher \"{mountPoint}\" ist beinahe voll ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Dein Speicher ist beinahe voll ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["stimmt mit \"{filter}\" überein","stimmen mit \"{filter}\" überein"],
    "View in folder" : "In Ordner anzeigen",
    "Copied!" : "Kopiert!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Benutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
    "Path" : "Pfad",
    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
    "Favorited" : "Favorisiert",
    "Favorite" : "Favorit",
    "You can only favorite a single file or folder at a time" : "Du kannst gleichzeitig nur eine Datei oder einen Ordner als Favorit markieren",
    "New folder" : "Neuer Ordner",
    "Upload file" : "Datei hochladen",
    "Recent" : "Neueste",
    "Not favorited" : "Nicht favorisiert",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
    "Added to favorites" : "Zu den Favoriten hinzugefügt",
    "Removed from favorites" : "Aus den Favoriten entfernt",
    "You added {file} to your favorites" : "Du hast {file} zu deinen Favoriten hinzugefügt",
    "You removed {file} from your favorites" : "Du hast {file} aus deinen Favoriten entfernt",
    "File changes" : "Dateiänderungen",
    "Created by {user}" : "Erstellt durch {user}",
    "Changed by {user}" : "Geändert durch {user}",
    "Deleted by {user}" : "Gelöscht durch {user}",
    "Restored by {user}" : "Wiederhergestellt durch {user}",
    "Renamed by {user}" : "Umbenannt durch {user}",
    "Moved by {user}" : "Verschoben durch {user}",
    "\"remote user\"" : "„Externer Benutzer“",
    "You created {file}" : "Du hast {file} erstellt",
    "You created an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} erstellt",
    "{user} created {file}" : "{user} hat {file} erstellt",
    "{user} created an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} erstellt",
    "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
    "You changed {file}" : "Du hast {file} geändert",
    "You changed an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} geändert",
    "{user} changed {file}" : "{user} hat {file} geändert",
    "{user} changed an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} geändert",
    "You deleted {file}" : "Du hast {file} gelöscht",
    "You deleted an encrypted file in {file}" : "Du hast eine verschlüsselte Datei in {file} gelöscht",
    "{user} deleted {file}" : "{user} hat {file} gelöscht",
    "{user} deleted an encrypted file in {file}" : "{user} hat eine verschlüsselte Datei in {file} gelöscht",
    "You restored {file}" : "Du hast {file} wiederhergestellt",
    "{user} restored {file}" : "{user} hat {file} wiederhergestellt",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Du hast {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} (hidden) to {newfile}" : "Du hast {oldfile} (versteckt) in {newfile} umbenannt",
    "You renamed {oldfile} to {newfile} (hidden)" : "Du hast {oldfile} in {newfile} (versteckt) umbenannt",
    "You renamed {oldfile} to {newfile}" : "Du hast {oldfile} in {newfile} umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} hat {oldfile} (versteckt) in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} hat {oldfile} (versteckt) in {newfile} umbenannt",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} hat {oldfile} in {newfile} (versteckt) umbenannt",
    "{user} renamed {oldfile} to {newfile}" : "{user} hat {oldfile} in {newfile} umbenannt",
    "You moved {oldfile} to {newfile}" : "Du hast {oldfile} nach {newfile} verschoben",
    "{user} moved {oldfile} to {newfile}" : "{user} hat {oldfile} nach {newfile} verschoben",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde deinen <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
    "A file or folder has been <strong>changed</strong>" : "Eine Datei oder ein Ordner wurde <strong>geändert</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Eine favorisierte Datei oder ein Ordner wurde <strong>geändert</strong>",
    "All files" : "Alle Dateien",
    "Unlimited" : "Unbegrenzt",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "Accept" : "Akzeptieren",
    "Reject" : "Ablehnen",
    "Incoming ownership transfer from {user}" : "Eingehende Besitzübertragung von {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Soll {path} angenommen werden?\n\nInfo: Der Übertragungsprozess nach der Annahme kann bis zu einer Stunde dauern.",
    "Ownership transfer failed" : "Besitzübertragung fehlgeschlagen",
    "Your ownership transfer of {path} to {user} failed." : "Die Besitzübertragung von {path} an {user} ist fehlgeschlagen.",
    "The ownership transfer of {path} from {user} failed." : "Die Übertragung von {path} ist fehlgeschlagen.",
    "Ownership transfer done" : "Besitzübertragung abgeschlossen",
    "Your ownership transfer of {path} to {user} has completed." : "Die Besitzübertragung von {path} an {user} wurde fertiggestellt.",
    "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
    "in %s" : "in %s",
    "File Management" : "Dateiverwaltung",
    "Transfer ownership of a file or folder" : "Besitz einer Datei oder eines Ordners übertragen",
    "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Change" : "Ändern",
    "New owner" : "Neuer Besitzer",
    "Search users" : "Suche Benutzer",
    "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
    "Transfer" : "Übertragen",
    "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
    "Invalid path selected" : "Ungültiger Dateipfad ausgewählt",
    "Ownership transfer request sent" : "Anforderung für die Übertragung des Besitzes versandt",
    "Cannot transfer ownership of a file or folder you do not own" : "Der Besitz an einer Datei oder einem Ordner, der dir nicht gehört, kann nicht übertragen werden",
    "Tags" : "Schlagworte",
    "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei konnte nicht geändert werden",
    "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
    "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
    "Cancel" : "Abbrechen",
    "Create" : "Erstellen",
    "Create a new file with the selected template" : "Eine neue Datei anhand der ausgewählten Vorlage erstellen",
    "Creating file" : "Datei erstellen",
    "Blank" : "Leer",
    "Unable to create new file from template" : "Neue Datei konnte nicht aus Vorlage erstellt werden",
    "Set up templates folder" : "Vorlagenordner einrichten",
    "Templates" : "Vorlagen",
    "Unable to initialize the templates directory" : "Der Vorlagenordner konnte nicht initialisiert werden",
    "%s used" : "%s verwendet",
    "%1$s of %2$s used" : "%1$s von %2$s verwendet",
    "Files settings" : "Dateien-Einstellungen",
    "Show hidden files" : "Versteckte Dateien anzeigen",
    "Crop image previews" : "Bildvorschauen zuschneiden",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Diese Adresse benutzen, um über WebDAV auf deine Dateien zuzugreifen",
    "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
    "Toggle grid view" : "Rasteransicht umschalten",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Inhalte hochladen oder mit deinen Geräten synchronisieren!",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "No favorites yet" : "Noch keine Favoriten vorhanden",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
    "Deleted files" : "Gelöschte Dateien",
    "Shares" : "Freigaben",
    "Shared with others" : "Mit anderen geteilt",
    "Shared with you" : "Mit dir geteilt",
    "Shared by link" : "Über einen Link geteilt",
    "Deleted shares" : "Gelöschte Freigaben",
    "Pending shares" : "Ausstehende Freigaben",
    "Text file" : "Textdatei",
    "New text file.txt" : "Neue Textdatei file.txt",
    "Select" : "Auswählen",
    "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "New" : "Neu",
    "Cannot transfer ownership of a file or folder you don't own" : "Der Besitz einer Datei oder eines Ordners, den du nicht besitzt, kann nicht übertragen werden",
    "%s%% of %s used" : "%s%% von %s verwendet",
    "Settings" : "Einstellungen"
},
"nplurals=2; plural=(n != 1);");
